//
#include "Define.h"
//
#ifndef NtpDateTime_h
#define NtpDateTime_h
//
#include <WiFi.h>
#include "time.h"
//
//----------------------
//  Include
//----------------------
#include <Arduino.h>
#include <SerialUart.h>
//
class CNtpDateTime
{
    protected:
    //TTerm FPTerm;
    //TMessage FPMessage;
    //TError FPError;
    char FBuffer[16];
    //
    public:
    // Instance
    CNtpDateTime(void);
    // Property
    IPAddress GetLocalIPAddress(void);
    bool IsConnected(void);
    // Handler
    void DisconnectWifi(void);
    void SetWifiModeOff(void);
    void ConnectWifi(const char* ssid, const char* password);
    void Initialise(const char* ntpserver, long gmtoffset, 
                    int daylightoffset);
    const char* GetDateTimeS(void);
    const char* GetDateS(void);
    const char* GetTimeS(void);
};
//
#endif // NtpDateTime_h
//